@@ -3,19 +3,8 @@
 """
 Copyright (C) 2009-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-Kajongg is free software you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation either version 2 of the License, or
-(at your option) any later version.
+SPDX-License-Identifier: GPL-2.0
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
 import datetime
@@ -113,16 +102,17 @@ class ClientTable(Table):
         return False
 
     def __str__(self):
-        onlineNames = list(x for x in self.playerNames if self.isOnline(x))
+        onlineNames = [x for x in self.playerNames if self.isOnline(x)]
         offlineString = ''
-        offlineNames = list(x for x in self.playerNames if x not in onlineNames
-                            and not x.startswith('Robot'))
+        offlineNames = [
+            x for x in self.playerNames if x not in onlineNames
+            and not x.startswith('Robot')]
         if offlineNames:
             offlineString = ' offline:' + ','.join(offlineNames)
         return '%d(%s %s%s)' % (self.tableid, self.ruleset.name, ','.join(onlineNames), offlineString)
 
     def gameExistsLocally(self):
-        """does the game exist in the data base of the client?"""
+        """True if the game exists in the data base of the client"""
         assert self.gameid
         return bool(Query('select 1 from game where id=?', (self.gameid,)).records)
 
@@ -147,6 +137,7 @@ class Client(pb.Referenceable):
         """hide weakref"""
         if self._table:
             return self._table()
+        return None
 
     @table.setter
     def table(self, value):
@@ -168,12 +159,13 @@ class Client(pb.Referenceable):
                 Internal.scene.mainWindow.updateGUI()
 
     def _tableById(self, tableid):
-        """returns table with tableid"""
+        """return table with tableid"""
         for table in self.tables:
             if table.tableid == tableid:
                 return table
+        return None
 
-    def logout(self, dummyResult=None):  # pylint: disable=no-self-use
+    def logout(self, unusedResult=None):  # pylint: disable=no-self-use
         """virtual"""
         return succeed(None)
 
@@ -192,7 +184,7 @@ class Client(pb.Referenceable):
 
     def remote_newTables(self, tables):
         """update table list"""
-        newTables = list(ClientTable(self, *x) for x in tables)
+        newTables = [ClientTable(self, *x) for x in tables]
         self.tables.extend(newTables)
         if Debug.table:
             _ = ', '.join(str(ClientTable(self, *x)) for x in tables)
@@ -206,7 +198,7 @@ class Client(pb.Referenceable):
         the server always only sends the hash and the client then says "I do
         not know this ruleset, please send definition", but that would mean
         more changes to the client code"""
-        return list(x for x in hashes if not Ruleset.hashIsKnown(x))
+        return [x for x in hashes if not Ruleset.hashIsKnown(x)]
 
     def tableChanged(self, table):
         """update table list"""
@@ -217,7 +209,7 @@ class Client(pb.Referenceable):
             self.tables.append(newTable)
         return oldTable, newTable
 
-    def remote_tableRemoved(self, tableid, dummyMsg, *dummyMsgArgs):
+    def remote_tableRemoved(self, tableid, message, *args):  # pylint: disable=unused-argument
         """update table list"""
         table = self._tableById(tableid)
         if table:
@@ -240,6 +232,7 @@ class Client(pb.Referenceable):
             for key, value in module.__dict__.items():
                 if key == 'AI' + aiName:
                     return value
+        return None
 
     def __assignIntelligence(self):
         """assign intelligence to myself. All players already have default intelligence."""
@@ -307,7 +300,7 @@ class Client(pb.Referenceable):
             # latest move first
             if move.message == Message.Discard:
                 break
-            elif move.message == Message.NoClaim and move.notifying:
+            if move.message == Message.NoClaim and move.notifying:
                 noClaimCount += 1
                 if noClaimCount == 2:
                     if Debug.delayChow:
@@ -328,8 +321,8 @@ class Client(pb.Referenceable):
         return result
 
     def ask(self, move, answers):
-        """this is where the robot AI should go.
-        sends answer and one parameter to server"""
+        """place the robot AI here.
+        send answer and one parameter to server"""
         delay = 0.0
         delayStep = 0.1
         myself = self.game.myself
@@ -343,7 +336,7 @@ class Client(pb.Referenceable):
         return succeed(result)
 
     def thatWasMe(self, player):
-        """returns True if player == myself"""
+        """return True if player == myself"""
         if not self.game:
             return False
         return player == self.game.myself
@@ -351,12 +344,9 @@ class Client(pb.Referenceable):
     @staticmethod
     def __jellyMessage(value):
         """the Message classes are not pb.copyable, convert them into their names"""
-        if value is None:
-            return Message.OK.name
-        else:
-            return Message.jelly(value, value)
+        return Message.OK.name if value is None else Message.jelly(value, value)
 
-    def remote_move(self, playerName, command, *dummyArgs, **kwargs):
+    def remote_move(self, playerName, command, *unusedArgs, **kwargs): # pylint: disable=unused-argument
         """the server sends us info or a question and always wants us to answer"""
         if Internal.scene and not isAlive(Internal.scene):
             return fail()
@@ -422,7 +412,7 @@ class Client(pb.Referenceable):
             # before the animated tile reaches its end position
             animate()
             return answer
-        elif message == Message.AskForClaims:
+        if message == Message.AskForClaims:
             # no need to start an animation. If we did the below standard clause, this is what
             # could happen:
             # 1. user says Chow
@@ -431,10 +421,9 @@ class Client(pb.Referenceable):
             # 4. but this answer is Chow, without a selected Chow. This is
             # wrongly sent to server
             return answer
-        else:
-            # return answer only after animation ends. Put answer into
-            # the Deferred returned by animate().
-            return animate().addCallback(lambda x: answer)
+        # return answer only after animation ends. Put answer into
+        # the Deferred returned by animate().
+        return animate().addCallback(lambda x: answer)
 
     def claimed(self, move):
         """somebody claimed a discarded tile"""
@@ -466,6 +455,7 @@ class Client(pb.Referenceable):
             # even here we ask: if our discard is claimed we need time
             # to notice - think 3 robots or network timing differences
             return self.ask(move, [Message.OK])
+        return None
 
     def myAction(self, move):
         """ask myself what I want to do after picking or claiming a tile"""
