@@ -2,14 +2,8 @@
 Copyright (c) 2007-2008 Qtrac Ltd <mark@qtrac.eu>
 Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
- This program or module is free software: you can redistribute it and/or
- modify it under the terms of the GNU General Public License as published
- by the Free Software Foundation, either version 2 of the License, or
- version 3 of the License, or (at your option) any later version. It is
- provided for educational purposes and is distributed in the hope that
- it will be useful, but WITHOUT ANY WARRANTY; without even the implied
- warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
- the GNU General Public License for more details.
+SPDX-License-Identifier: GPL-2.0
+
 """
 
 from qt import Qt, QSize, QRect, QEvent
@@ -29,7 +23,7 @@ class ZeroEmptyColumnDelegate(QStyledItemDelegate):
             return ''
         if isinstance(value, float) and value == 0.0:
             return ''
-        return super(ZeroEmptyColumnDelegate, self).displayText(value, locale)
+        return super().displayText(value, locale)
 
 class RichTextColumnDelegate(QStyledItemDelegate):
 
@@ -38,7 +32,7 @@ class RichTextColumnDelegate(QStyledItemDelegate):
     document = None
 
     def __init__(self, parent=None):
-        super(RichTextColumnDelegate, self).__init__(parent)
+        super().__init__(parent)
         if self.label is None:
             self.label = QLabel()
             self.label.setIndent(5)
@@ -74,7 +68,7 @@ class RightAlignedCheckboxDelegate(QStyledItemDelegate):
 https://wiki.qt.io/Technical_FAQ#How_can_I_align_the_checkboxes_in_a_view.3F"""
 
     def __init__(self, parent, cellFilter):
-        super(RightAlignedCheckboxDelegate, self).__init__(parent)
+        super().__init__(parent)
         self.cellFilter = cellFilter
 
     @staticmethod
