@@ -3,19 +3,8 @@
 """
 Copyright (C) 2009-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-Kajongg is free software you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation either version 2 of the License, or
-(at your option) any later version.
+SPDX-License-Identifier: GPL-2.0
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
 import random
@@ -75,7 +64,7 @@ class SelectChow(KDialogIgnoringEscape):
             if chow == propose:
                 self.buttons[idx].setFocus()
 
-    def toggled(self, dummyChecked):
+    def toggled(self, unusedChecked):
         """a radiobutton has been toggled"""
         button = self.sender()
         if button.isChecked():
@@ -109,7 +98,7 @@ class SelectKong(KDialogIgnoringEscape):
         widget.setLayout(layout)
         self.setMainWidget(widget)
 
-    def toggled(self, dummyChecked):
+    def toggled(self, unusedChecked):
         """a radiobutton has been toggled"""
         button = self.sender()
         if button.isChecked():
@@ -230,7 +219,7 @@ class ClientDialog(QDialog):
 
     def messages(self):
         """a list of all messages returned by the declared buttons"""
-        return list(x.message for x in self.buttons)
+        return [x.message for x in self.buttons]
 
     def proposeAction(self):
         """either intelligently or first button by default. May also
@@ -321,11 +310,11 @@ class ClientDialog(QDialog):
             idx if vertical else 0,
             idx if not vertical else 0)
 
-        geometry.setWidth(width)
-        geometry.setHeight(height)
+        geometry.setWidth(int(width))
+        geometry.setHeight(int(height))
         self.setGeometry(geometry)
 
-    def showEvent(self, dummyEvent):
+    def showEvent(self, unusedEvent):
         """try to place the dialog such that it does not cover interesting information"""
         self.placeInField()
 
@@ -365,7 +354,7 @@ class ClientDialog(QDialog):
         Internal.scene.clientDialog = None
         self.deferred.callback(answer)
 
-    def selectedAnswer(self, dummyChecked):
+    def selectedAnswer(self, unusedChecked):
         """the user clicked one of the buttons"""
         game = self.client.game
         if game and not game.autoPlay:
@@ -398,7 +387,7 @@ class HumanClient(Client):
             """return True if clients is cleaned"""
             return len(clients) == 0 or (exception and clients == [exception])
 
-        def disconnectedClient(dummyResult, client):
+        def disconnectedClient(unusedResult, client):
             """now the client is really disconnected from the server"""
             if client in clients:
                 # HumanClient.serverDisconnects also removes it!
@@ -442,7 +431,7 @@ class HumanClient(Client):
                         voiceId, maxGameId,
                         Internal.defaultPort).addCallbacks(self.__initTableList, self.__versionError)
 
-    def __initTableList(self, dummy):
+    def __initTableList(self, unused):
         """first load of the list. Process options like --demo, --table, --join"""
         self.showTableList()
         if SingleshotOptions.table:
@@ -451,8 +440,7 @@ class HumanClient(Client):
                 self.__showTables).addErrback(self.tableError)
             if Debug.table:
                 logDebug(
-                    '%s: --table lets us open an new table %d' %
-                    (self.name, SingleshotOptions.table))
+                    '%s: --table lets us open a new table' % self.name)
             SingleshotOptions.table = False
         elif SingleshotOptions.join:
             Internal.autoPlay = False
@@ -470,7 +458,7 @@ class HumanClient(Client):
             self.__showTables()
 
     @staticmethod
-    def __loginFailed(dummy):
+    def __loginFailed(unused):
         """as the name says"""
         if Internal.scene:
             Internal.scene.startingGame = False
@@ -497,13 +485,13 @@ class HumanClient(Client):
         if self.tableList:
             self.tableList.loadTables(self.tables)
 
-    def __showTables(self, dummy=None):
+    def __showTables(self, unused=None):
         """load and show tables. We may be used as a callback. In that case,
         clientTables is the id of a new table - which we do not need here"""
         self.tableList.loadTables(self.tables)
         self.tableList.show()
 
-    def showTableList(self, dummy=None):
+    def showTableList(self, unused=None):
         """allocate it if needed"""
         if not self.tableList:
             self.tableList = TableList(self)
@@ -525,23 +513,21 @@ class HumanClient(Client):
             if self.hasLocalServer():
                 # when playing a local game, only show pending tables with
                 # previously selected ruleset
-                self.tables = list(
-                    x for x in self.tables if x.ruleset == self.ruleset)
-        if len(self.tables):
+                self.tables = [x for x in self.tables if x.ruleset == self.ruleset]
+        if self.tables:
             self.__updateTableList()
 
     def remote_newTables(self, tables):
         """update table list"""
-        assert len(tables)
+        assert tables
 
         def gotRulesets(result):
             """the server sent us the wanted ruleset definitions"""
             for ruleset in result:
                 Ruleset.cached(ruleset).save()  # make it known to the cache and save in db
             return tables
-        rulesetHashes = set(x[1] for x in tables)
-        needRulesets = list(
-            x for x in rulesetHashes if not Ruleset.hashIsKnown(x))
+        rulesetHashes = {x[1] for x in tables}
+        needRulesets = [x for x in rulesetHashes if not Ruleset.hashIsKnown(x)]
         if needRulesets:
             self.callServer(
                 'needRulesets',
@@ -571,12 +557,13 @@ class HumanClient(Client):
                 # others will then automatically leave too
                 for name in oldTable.playerNames:
                     if name != self.name and not newTable.isOnline(name):
-                        def sorried(dummy):
+                        def sorried(unused):
                             """user ack"""
                             game = self.game
                             if game:
                                 self.game = None
                                 return game.close()
+                            return None
                         if self.beginQuestion:
                             self.beginQuestion.cancel()
                         Sorry(i18n('Player %1 has left the table', name)).addCallback(
@@ -617,10 +604,9 @@ class HumanClient(Client):
             if self.connection and result:
                 # still connected and yes, we are
                 return clientReady()
-            else:
-                return Message.NoGameStart
+            return Message.NoGameStart
 
-        def cancelled(dummy):
+        def cancelled(unused):
             """the user does not want to start now. Back to table list"""
             if Debug.table:
                 logDebug('%s: Readyforgamestart returns Message.NoGameStart for table %s' % (
@@ -651,13 +637,12 @@ class HumanClient(Client):
 
     def readyForHandStart(self, playerNames, rotateWinds):
         """playerNames are in wind order ESWN. Never called for first hand."""
-        def answered(dummy=None):
+        def answered(unused=None):
             """called after the client player said yes, I am ready"""
-            if self.connection:
-                return Client.readyForHandStart(self, playerNames, rotateWinds)
+            return Client.readyForHandStart(self, playerNames, rotateWinds) if self.connection else None
         if not self.connection:
             # disconnected meanwhile
-            return
+            return None
         if Options.gui:
             # update the balances in the status bar:
             Internal.mainWindow.updateGUI()
@@ -746,8 +731,7 @@ class HumanClient(Client):
             # this does not specify any tiles, the server does not need this. Robot players
             # also return None in this case.
             return answer
-        else:
-            return answer, args
+        return answer, args
 
     def __answerError(self, answer, move, answers):
         """an error happened while determining the answer to server"""
@@ -767,7 +751,7 @@ class HumanClient(Client):
 
     def remote_gameOver(self, tableid, message, *args):
         """the game is over"""
-        def yes(dummy):
+        def yes(unused):
             """now that the user clicked the 'game over' prompt away, clean up"""
             if self.game:
                 self.game.rotateWinds()
@@ -798,8 +782,10 @@ class HumanClient(Client):
         scene = Internal.scene
         if scene and game and scene.game == game:
             scene.game = None
+        if not Options.gui:
+            Internal.mainWindow.close()
 
-    def serverDisconnected(self, dummyReference):
+    def serverDisconnected(self, unusedReference):
         """perspective calls us back"""
         if self.connection and (Debug.traffic or Debug.connections):
             logDebug(
@@ -869,7 +855,7 @@ class HumanClient(Client):
             table = self.tableList.selectedTable()
         self.callServer('joinTable', table.tableid).addErrback(self.tableError)
 
-    def logout(self, dummyResult=None):
+    def logout(self, unusedResult=None):
         """clean visual traces and logout from server"""
         def loggedout(result, connection):
             """end the connection from client side"""
@@ -883,8 +869,7 @@ class HumanClient(Client):
             if Debug.connections:
                 logDebug('sending logout to server for {}'.format(self))
             return self.callServer('logout').addCallback(loggedout, conn)
-        else:
-            return succeed(None)
+        return succeed(None)
 
     def __logCallServer(self, *args):
         """for Debug.traffic"""
@@ -914,8 +899,7 @@ class HumanClient(Client):
                 def callServerError(result):
                     """if serverDisconnected has been called meanwhile, just ignore msg about
                     connection lost in a non-clean fashion"""
-                    if self.connection:
-                        return result
+                    return result if self.connection else None
                 return self.connection.perspective.callRemote(*args).addErrback(callServerError)
             except pb.DeadReferenceError:
                 logWarning(
