@@ -3,19 +3,8 @@
 """
 Copyright (C) 2009-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-Kajongg is free software you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation either version 2 of the License, or
-(at your option) any later version.
+SPDX-License-Identifier: GPL-2.0
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 The DBPasswordChecker is based on an example from the book
 Twisted Network Programming Essentials by Abe Fettig, 2006
@@ -25,10 +14,7 @@ O'Reilly Media, Inc., ISBN 0-596-10032-9
 import os
 import random
 import traceback
-if os.name != 'nt':
-    import resource
 from itertools import chain
-
 from twisted.spread import pb
 
 from common import Debug, Internal, StrMixin
@@ -49,6 +35,10 @@ from servercommon import srvError
 from user import User
 from game import PlayingGame
 
+if os.name != 'nt':
+    import resource
+
+
 class ServerGame(PlayingGame):
 
     """the central game instance on the server"""
@@ -68,7 +58,7 @@ class ServerGame(PlayingGame):
         self.shouldSave = True
 
     def throwDices(self):
-        """sets random living and kongBox
+        """set random living and kongBox
         sets divideAt: an index for the wall break"""
         self.wall.tiles.sort()
         self.randomGenerator.shuffle(self.wall.tiles)
@@ -116,7 +106,7 @@ class ServerTable(Table, StrMixin):
             logDebug('new table %s' % self)
 
     def hasName(self, name):
-        """returns True if one of the players in the game is named 'name'"""
+        """return True if one of the players in the game is named 'name'"""
         return bool(self.game) and any(x.name == name for x in self.game.players)
 
     def asSimpleList(self, withFullRuleset=False):
@@ -129,8 +119,7 @@ class ServerTable(Table, StrMixin):
             names = tuple(x.name for x in self.users)
         online = tuple(bool(x in onlineNames) for x in names)
         if game:
-            endValues = game.handctr, dict(
-                (x.wind.char, x.balance) for x in game.players)
+            endValues = game.handctr, {x.wind.char: x.balance for x in game.players}
         else:
             endValues = None
         return list([
@@ -164,7 +153,7 @@ class ServerTable(Table, StrMixin):
 
     def addUser(self, user):
         """add user to this table"""
-        if user.name in list(x.name for x in self.users):
+        if user.name in (x.name for x in self.users):
             raise srvError(pb.Error, i18nE('You already joined this table'))
         if len(self.users) == self.maxSeats():
             raise srvError(pb.Error, i18nE('All seats are already taken'))
@@ -200,14 +189,14 @@ class ServerTable(Table, StrMixin):
     def __str__(self):
         """for debugging output"""
         if self.users:
-            onlineNames = list(x.name + ('(Owner)' if self.owner and x == self.owner.name else '')
-                               for x in self.users)
+            onlineNames = [x.name + ('(Owner)' if self.owner and x == self.owner.name else '')
+                           for x in self.users]
         else:
-            onlineNames = list(['no users yet'])
+            onlineNames = ['no users yet']
         offlineString = ''
         if self.game:
-            offlineNames = list(x.name for x in self.game.players if x.name not in onlineNames
-                                and not x.name.startswith('Robot'))
+            offlineNames = [x.name for x in self.game.players if x.name not in onlineNames
+                            and not x.name.startswith('Robot')]
             if offlineNames:
                 offlineString = ' offline:' + ','.join(offlineNames)
         return '%d(%s%s)' % (self.tableid, ','.join(onlineNames), offlineString)
@@ -222,8 +211,8 @@ class ServerTable(Table, StrMixin):
         return max(gameIds) + 1
 
     def __prepareNewGame(self):
-        """returns a new game object"""
-        names = list(x.name for x in self.users)
+        """return a new game object"""
+        names = [x.name for x in self.users]
         # the server and all databases save the english name but we
         # want to make sure a translation exists for the client GUI
         robotNames = [
@@ -236,8 +225,7 @@ class ServerTable(Table, StrMixin):
             i18ncE('kajongg, name of robot player, to be translated', 'Robot 3')]
         while len(names) < 4:
             names.append(robotNames[3 - len(names)])
-        names = list(tuple([Wind.all4[idx], name])
-                     for idx, name in enumerate(names))
+        names = [tuple([Wind.all4[idx], name]) for idx, name in enumerate(names)]
         self.client = Client()
                              # Game has a weakref to client, so we must keep
                              # it!
@@ -249,6 +237,7 @@ class ServerTable(Table, StrMixin):
         for result in self.users:
             if result.name == player.name:
                 return result
+        return None
 
     def __connectPlayers(self):
         """connects client instances with the game players"""
@@ -323,7 +312,7 @@ class ServerTable(Table, StrMixin):
                 if msg.answer == Message.NO:
                     self.proposeGameId(gameid + 1)
                     return
-                elif msg.answer != Message.OK:
+                if msg.answer != Message.OK:
                     raise srvError(
                         pb.Error,
                         'collectGameIdAnswers got neither NO nor OK')
@@ -339,13 +328,13 @@ class ServerTable(Table, StrMixin):
             block.tellPlayer(
                 player, Message.ReadyForGameStart, tableid=self.tableid,
                 gameid=game.gameid, shouldSave=player.shouldSave,
-                wantedGame=game.wantedGame, playerNames=list((x.wind, x.name) for x in game.players))
+                wantedGame=game.wantedGame, playerNames=[(x.wind, x.name) for x in game.players])
         block.callback(self.startGame)
 
     def startGame(self, requests):
         """if all players said ready, start the game"""
         for user in self.users:
-            userRequests = list(x for x in requests if x.user == user)
+            userRequests = [x for x in requests if x.user == user]
             if not userRequests or userRequests[0].answer == Message.NoGameStart:
                 if Debug.table:
                     if not userRequests:
@@ -377,8 +366,7 @@ class ServerTable(Table, StrMixin):
             for tableid in self.server.tablesWith(user):
                 if tableid != self.tableid:
                     self.server.leaveTable(user, tableid)
-        foreigners = list(
-            x for x in self.server.srvUsers if x not in self.users)
+        foreigners = [x for x in self.server.srvUsers if x not in self.users]
         if foreigners:
             if Debug.table:
                 logDebug(
@@ -466,7 +454,7 @@ class ServerTable(Table, StrMixin):
                     voice, voiceFor.name))
         block.callback(self.assignVoices)
 
-    def assignVoices(self, dummyResults=None):
+    def assignVoices(self, unusedResults=None):
         """now all human players have all voice data needed"""
         humanPlayers = [
             x for x in self.game.players if isinstance(self.remotes[x], User)]
@@ -474,7 +462,7 @@ class ServerTable(Table, StrMixin):
         block.tell(None, humanPlayers, Message.AssignVoices)
         block.callback(self.startHand)
 
-    def pickTile(self, dummyResults=None, deadEnd=False):
+    def pickTile(self, unusedResults=None, deadEnd=False):
         """the active player gets a tile from wall. Tell all clients."""
         if not self.running:
             return
@@ -528,7 +516,7 @@ class ServerTable(Table, StrMixin):
         block.tellAll(player, Message.Discard, tile=tile)
         block.callback(self._clientDiscarded2, msg, dangerousText, mustPlayDangerous, violates)
 
-    def _clientDiscarded2(self, dummyResults, msg, dangerousText, mustPlayDangerous, violates):
+    def _clientDiscarded2(self, unusedResults, msg, dangerousText, mustPlayDangerous, violates):
         """client told us he discarded a tile. Continue, check for violating original call"""
         block = DeferredBlock(self)
         player = msg.player
@@ -540,7 +528,7 @@ class ServerTable(Table, StrMixin):
             block.tellAll(player, Message.ViolatesOriginalCall)
         block.callback(self._clientDiscarded3, msg, dangerousText, mustPlayDangerous)
 
-    def _clientDiscarded3(self, dummyResults, msg, dangerousText, mustPlayDangerous):
+    def _clientDiscarded3(self, unusedResults, msg, dangerousText, mustPlayDangerous):
         """client told us he discarded a tile. Continue, check for calling"""
         block = DeferredBlock(self)
         player = msg.player
@@ -550,7 +538,7 @@ class ServerTable(Table, StrMixin):
                 block.tellAll(player, Message.Calling)
         block.callback(self._clientDiscarded4, msg, dangerousText, mustPlayDangerous)
 
-    def _clientDiscarded4(self, dummyResults, msg, dangerousText, mustPlayDangerous):
+    def _clientDiscarded4(self, unusedResults, msg, dangerousText, mustPlayDangerous):
         """client told us he discarded a tile. Continue, check for dangerous game"""
         block = DeferredBlock(self)
         player = msg.player
@@ -581,7 +569,7 @@ class ServerTable(Table, StrMixin):
         else:
             block.callback(self._askForClaims, msg)
 
-    def clientMadeOriginalCall(self, dummyResults, msg):
+    def clientMadeOriginalCall(self, unusedResults, msg):
         """first tell everybody about original call
         and then treat the implicit discard"""
         msg.player.originalCall = True
@@ -591,7 +579,7 @@ class ServerTable(Table, StrMixin):
         block.tellAll(msg.player, Message.OriginalCall)
         block.callback(self._askForClaims, msg)
 
-    def startHand(self, dummyResults=None):
+    def startHand(self, unusedResults=None):
         """all players are ready to start a hand, so do it"""
         if self.running:
             self.game.prepareHand()
@@ -600,7 +588,7 @@ class ServerTable(Table, StrMixin):
                                  divideAt=self.game.divideAt)
             block.callback(self.divided)
 
-    def divided(self, dummyResults=None):
+    def divided(self, unusedResults=None):
         """the wall is now divided for all clients"""
         if not self.running:
             return
@@ -615,7 +603,7 @@ class ServerTable(Table, StrMixin):
                            tiles=TileList(chain(tiles, player.bonusTiles)))
         block.callback(self.dealt)
 
-    def endHand(self, dummyResults=None):
+    def endHand(self, unusedResults=None):
         """hand is over, show all concealed tiles to all players"""
         if not self.running:
             return
@@ -632,14 +620,14 @@ class ServerTable(Table, StrMixin):
                         tiles=TileList(player.concealedTiles))
             block.callback(self.saveHand)
 
-    def saveHand(self, dummyResults=None):
+    def saveHand(self, unusedResults=None):
         """save the hand to the database and proceed to next hand"""
         if not self.running:
             return
         self.tellAll(None, Message.SaveHand, self.nextHand)
         self.game.saveHand()
 
-    def nextHand(self, dummyResults):
+    def nextHand(self, unusedResults):
         """next hand: maybe rotate"""
         if not self.running:
             return
@@ -665,7 +653,7 @@ class ServerTable(Table, StrMixin):
                     resource.getrusage(resource.RUSAGE_SELF).ru_maxrss)
             return
         self.game.sortPlayers()
-        playerNames = list((x.wind, x.name) for x in self.game.players)
+        playerNames = [(x.wind, x.name) for x in self.game.players]
         self.tellAll(None, Message.ReadyForHandStart, self.startHand,
                      playerNames=playerNames, rotateWinds=rotateWinds, token=token)
 
@@ -799,7 +787,7 @@ class ServerTable(Table, StrMixin):
             lastMeld=lastMeld, withDiscardTile=withDiscard)
         block.callback(self.endHand)
 
-    def dealt(self, dummyResults):
+    def dealt(self, unusedResults):
         """all tiles are dealt, ask east to discard a tile"""
         if self.running:
             self.tellAll(
@@ -818,9 +806,9 @@ class ServerTable(Table, StrMixin):
                 self.pickTile)
 
     def prioritize(self, requests):
-        """returns only requests we want to execute"""
+        """return only requests we want to execute"""
         if not self.running:
-            return
+            return None
         answers = [
             x for x in requests if x.answer not in [
                 Message.NoClaim,
@@ -848,7 +836,7 @@ class ServerTable(Table, StrMixin):
                 x for x in answers if x.player == nextPlayer or x.answer != Message.MahJongg]
         return answers
 
-    def _askForClaims(self, dummyRequests, dummyMsg):
+    def _askForClaims(self, unusedRequests, unusedMsg):
         """ask all players if they want to claim"""
         if self.running:
             self.tellOthers(
@@ -859,10 +847,10 @@ class ServerTable(Table, StrMixin):
     def processAnswers(self, requests):
         """a player did something"""
         if not self.running:
-            return
+            return None
         answers = self.prioritize(requests)
         if not answers:
-            return
+            return None
         for answer in answers:
             msg = '<-  %s' % answer
             if Debug.traffic:
@@ -895,4 +883,3 @@ class ServerTable(Table, StrMixin):
         block.tellOthers(player, command, **kwargs)
         block.callback(callback)
         return block
-
