@@ -3,31 +3,18 @@
 """
 Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-Kajongg is free software you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation either version 2 of the License, or
-(at your option) any later version.
+SPDX-License-Identifier: GPL-2.0
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
 # util must not import from log because util should not
 # depend on kde.py
 
-from __future__ import print_function
 import traceback
 import os
 import datetime
 import subprocess
 import gc
-import csv
 
 
 from locale import getpreferredencoding
@@ -40,11 +27,11 @@ try:
 except AttributeError:
     STDOUTENCODING = None
 if not STDOUTENCODING:
-    STDOUTENCODING = getpreferredencoding() # pylint: disable=redefined-variable-type
+    STDOUTENCODING = getpreferredencoding()
 
 
 def stack(msg, limit=6):
-    """returns a list of lines with msg as prefix"""
+    """return a list of lines with msg as prefix"""
     result = []
     for idx, values in enumerate(
             traceback.extract_stack(limit=limit + 2)[:-2]):
@@ -58,7 +45,7 @@ def stack(msg, limit=6):
 
 
 def callers(count=5, exclude=None):
-    """returns the name of the calling method"""
+    """return the name of the calling method"""
     stck = traceback.extract_stack(limit=30)
     excluding = list(exclude) if exclude else []
     excluding.extend(['<genexpr>', '__call__', 'run', '<module>', 'runTests'])
@@ -71,14 +58,14 @@ def callers(count=5, exclude=None):
     excluding.extend(['_dataReceived', 'dataReceived', 'gotItem'])
     excluding.extend(['callWithContext', '_doReadOrWrite', 'doRead'])
     excluding.extend(['callers', 'debug', 'logMessage', 'logDebug'])
-    _ = list(([x[2] for x in stck if x[2] not in excluding]))
+    _ = list(x[2] for x in stck if x[2] not in excluding)
     names = reversed(_[-count:])
     result = '.'.join(names)
     return '[{}]'.format(result)
 
 
 def elapsedSince(since):
-    """returns seconds since since"""
+    """return seconds since since"""
     delta = datetime.datetime.now() - since
     return float(
         delta.microseconds
@@ -86,11 +73,12 @@ def elapsedSince(since):
 
 
 def which(program):
-    """returns the full path for the binary or None"""
+    """return the full path for the binary or None"""
     for path in os.environ['PATH'].split(os.pathsep):
         fullName = os.path.join(path, program)
         if os.path.exists(fullName):
             return fullName
+    return None
 
 
 def removeIfExists(filename):
@@ -167,8 +155,7 @@ class Duration:
                     diff.microseconds)
                 if self.bug:
                     raise UserWarning(msg)
-                else:
-                    print(msg)
+                print(msg)
 
 
 def checkMemory():
@@ -214,59 +201,9 @@ def gitHead():
         return None
     subprocess.Popen(['git', 'update-index', '-q', '--refresh'])
     uncommitted = list(popenReadlines('git diff-index --name-only HEAD --'))
-    if uncommitted:
-        return 'current'
-    else:
-        return next(popenReadlines('git log -1 --format=%h'))
+    return 'current' if uncommitted else next(popenReadlines('git log -1 --format=%h'))
 
 
-def xToUtf8(msg, args=None):
-    """makes sure msg and all args are utf-8"""
-    if args is not None:
-        return msg, args
-    else:
-        return msg
-    if isinstance(msg, str):
-        msg = msg.encode('utf-8')
-    elif not isinstance(msg, bytes):
-        msg = str(msg).encode('utf-8')
-    if args is not None:
-        args = list(args[:])
-        for idx, arg in enumerate(args):
-            if isinstance(arg, str):
-                args[idx] = arg.encode('utf-8')
-            elif not isinstance(arg, bytes):
-                args[idx] = str(arg).encode('utf-8')
-        return msg, args
-    else:
-        return msg
-
-
-class CsvWriter:
-    """hide differences between Python 2 and 3"""
-    def __init__(self, filename, mode='w'):
-        self.outfile = open(filename, mode)
-        self.__writer = csv.writer(self.outfile, delimiter=Csv.delimiter)
-
-    def writerow(self, row):
-        """write one row"""
-        self.__writer.writerow(list(
-            cell if isinstance(cell, str) else str(cell) for cell in row))
-
-    def __del__(self):
-        """clean up"""
-        self.outfile.close()
-
-class Csv:
-    """hide differences between Python 2 and 3"""
-
-    delimiter = ';'
-
-    @staticmethod
-    def reader(filename):
-        """returns a generator for decoded strings"""
-        return csv.reader(open(filename, 'r', encoding='utf-8'), delimiter=Csv.delimiter)
-
 def popenReadlines(args):
     """runs a subprocess and returns stdout as a list of unicode encodes lines"""
     if isinstance(args, str):
